from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic import BaseModel, Field, StrictStr, conlist

from xingchen.models.message import Message
from xingchen.models.extract_data import ExtractData


class Memory(BaseModel):
    summaries: Optional[conlist(StrictStr)] = Field(None, alias="summaries")
    originals: Optional[conlist(Message)] = Field(None, alias="originals")
    tags: Optional[conlist(ExtractData)] = Field(None, alias="tags")
    __properties = ["summaries", "originals", "tags"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Memory:
        """Create an instance of Memory from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Memory:
        """Create an instance of Memory from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Memory.parse_obj(obj)

        _obj = Memory.parse_obj({
            "summaries": obj.get("summaries"),
            "originals": [Message.from_dict(_item) for _item in obj.get("originals")] if obj.get(
                "originals") is not None else None,
            "tags": [ExtractData.from_dict(_item) for _item in obj.get("tags")] if obj.get(
                "tags") is not None else None
        })
        return _obj




from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

from xingchen.models.knowledge_base_dto import KnowledgeBaseDTO


class ResultDTOKnowledgeBaseDTO(BaseModel):
    request_id: Optional[StrictStr] = Field(None, alias="requestId")
    code: Optional[StrictInt] = None
    error_message: Optional[StrictStr] = Field(None, alias="errorMessage")
    error_message_key: Optional[StrictStr] = Field(None, alias="errorMessageKey")
    data: Optional[KnowledgeBaseDTO] = None
    success: Optional[StrictBool] = None
    __properties = ["requestId", "code", "errorMessage", "errorMessageKey", "data", "success"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ResultDTOKnowledgeBaseDTO:
        """Create an instance of ResultDTOKnowledgeBaseDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of data
        if self.data:
            _dict['data'] = self.data.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ResultDTOKnowledgeBaseDTO:
        """Create an instance of ResultDTOKnowledgeBaseDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ResultDTOKnowledgeBaseDTO.parse_obj(obj)

        _obj = ResultDTOKnowledgeBaseDTO.parse_obj({
            "request_id": obj.get("requestId"),
            "code": obj.get("code"),
            "error_message": obj.get("errorMessage"),
            "error_message_key": obj.get("errorMessageKey"),
            "data": KnowledgeBaseDTO.from_dict(obj.get("data")) if obj.get("data") is not None else None,
            "success": obj.get("success")
        })
        return _obj



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from xingchen.models.chat_history_query_dto import ChatHistoryQueryDTO  # noqa: E501

class TestChatHistoryQueryDTO(unittest.TestCase):
    """ChatHistoryQueryDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatHistoryQueryDTO:
        """Test ChatHistoryQueryDTO
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatHistoryQueryDTO`
        """
        model = ChatHistoryQueryDTO()  # noqa: E501
        if include_optional:
            return ChatHistoryQueryDTO(
                where = xingchen.models.chat_history_query_where.ChatHistoryQueryWhere(
                    character_id = '', 
                    session_id = '', 
                    start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    message_ids = [
                        ''
                        ], ),
                order_by = [
                    ''
                    ],
                page_num = 56,
                page_size = 56
            )
        else:
            return ChatHistoryQueryDTO(
        )
        """

    def testChatHistoryQueryDTO(self):
        """Test ChatHistoryQueryDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import Field, StrictStr, StrictBool, BaseModel, conlist

from xingchen.models.keyword import Keyword


class RejectCondition(BaseModel):
    enabled: Optional[StrictBool] = None
    condition_type: Optional[StrictStr] = Field(None, alias="conditionType")
    keywords: Optional[conlist(Keyword)] = Field(None, alias="keywords")
    sub_reject_condition: Optional[RejectCondition] = Field(None, alias="subRejectCondition")
    __properties = ["enabled", "conditionType", "keywords", "subRejectCondition"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RejectCondition:
        """Create an instance of RejectCondition from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RejectCondition:
        """Create an instance of RejectCondition from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RejectCondition.parse_obj(obj)

        _obj = RejectCondition.parse_obj({
            "enabled": obj.get("enabled"),
            "condition_type": obj.get("conditionType"),
            "keywords": [Keyword.from_dict(_item) for _item in obj.get("keywords")] if obj.get(
                "keywords") is not None else None,
            "sub_reject_condition": RejectCondition.from_dict(obj.get("subRejectCondition")) if obj.get(
                "subRejectCondition") is not None else None
        })
        return _obj



from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Optional

from pydantic import BaseModel, Field, conlist, StrictStr


class ExtractData(BaseModel):
    role: Optional[StrictStr] = Field(None, alias="role")
    key: Optional[StrictStr] = Field(None, alias="key")
    value: Optional[conlist(StrictStr)] = Field(None, alias="value")

    __properties = ["role", "key", "value"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ExtractData:
        """Create an instance of ExtractData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ExtractData:
        """Create an instance of ExtractData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ExtractData.parse_obj(obj)

        _obj = ExtractData.parse_obj({
            "role": obj.get("role"),
            "key": obj.get("key"),
            "value": obj.get("value")
        })
        return _obj



# coding: utf-8

"""
    XingChen 开放接口定义

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, Field, StrictBool

class Scenario(BaseModel):
    """
    Scenario
    """
    description: Optional[StrictStr] = None
    safety_prompt: Optional[StrictStr] = Field(None, alias="safetyPrompt", description="命中安全风险后，给大模型的提示信息")
    is_real_time: Optional[StrictBool] = Field(None, alias="isRealTime", description="是否为实时场景")
    __properties = ["description", "safetyPrompt", "isRealTime"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Scenario:
        """Create an instance of Scenario from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Scenario:
        """Create an instance of Scenario from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Scenario.parse_obj(obj)

        _obj = Scenario.parse_obj({
            "description": obj.get("description"),
            "is_real_time": obj.get("isRealTime")
        })
        return _obj





import re  # noqa: F401

from pydantic import Field
from pydantic import validate_arguments
from typing_extensions import Annotated

from xingchen.api_client import ApiClient
from xingchen.api_response import ApiResponse
from xingchen.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)
from xingchen.models.knowledge_base_create_dto import KnowledgeBaseCreateDTO
from xingchen.models.knowledge_base_delete_dto import KnowledgeBaseDeleteDTO
from xingchen.models.knowledge_base_detail_delete_dto import KnowledgeBaseDetailDeleteDTO
from xingchen.models.knowledge_base_detail_query_dto import KnowledgeBaseDetailQueryDTO
from xingchen.models.knowledge_base_detail_update_dto import KnowledgeBaseDetailUpdateDTO
from xingchen.models.knowledge_base_detail_upload_dto import KnowledgeBaseDetailUploadDTO
from xingchen.models.knowledge_base_query_dto import KnowledgeBaseQueryDTO
from xingchen.models.knowledge_base_update_dto import KnowledgeBaseUpdateDTO
from xingchen.models.result_dto_boolean import ResultDTOBoolean
from xingchen.models.result_dto_knowledge_base_dto import ResultDTOKnowledgeBaseDTO
from xingchen.models.result_dto_page_result_knowledge_base_detail_dto import ResultDTOPageResultKnowledgeBaseDetailDTO
from xingchen.models.result_dto_page_result_knowledge_base_dto import ResultDTOPageResultKnowledgeBaseDTO


class KnowledgeBaseApiSub:
    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    def version(self):
        return self.api_client.api_version()

    @validate_arguments
    def create(self, knowledge_base_create_dto: Annotated[
        KnowledgeBaseCreateDTO, Field(..., description="创建知识库请求")],
               **kwargs) -> ResultDTOKnowledgeBaseDTO:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the create_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.create_with_http_info(knowledge_base_create_dto, **kwargs)  # noqa: E501

    @validate_arguments
    def create_with_http_info(self, knowledge_base_create_dto: Annotated[
        KnowledgeBaseCreateDTO, Field(..., description="创建知识库请求")], **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'knowledge_base_create_dto'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['knowledge_base_create_dto'] is not None:
            _body_params = _params['knowledge_base_create_dto']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOKnowledgeBaseDTO",
        }

        return self.api_client.call_api(
            '/{0}/api/knowledge_base/create'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def update(self, knowledge_base_update_dto: Annotated[KnowledgeBaseUpdateDTO, Field(..., description="修改知识库请求")],
               **kwargs) -> ResultDTOBoolean:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the update_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.update_with_http_info(knowledge_base_update_dto, **kwargs)  # noqa: E501

    @validate_arguments
    def update_with_http_info(self, knowledge_base_update_dto: Annotated[
        KnowledgeBaseUpdateDTO, Field(..., description="修改知识库请求")], **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'knowledge_base_update_dto'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['knowledge_base_update_dto'] is not None:
            _body_params = _params['knowledge_base_update_dto']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOBoolean",
        }

        return self.api_client.call_api(
            '/{0}/api/knowledge_base/update'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def search(self, knowledge_base_query_dto: Annotated[KnowledgeBaseQueryDTO, Field(..., description="查询知识库请求")],
               **kwargs) -> ResultDTOPageResultKnowledgeBaseDTO:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the search_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.search_with_http_info(knowledge_base_query_dto, **kwargs)  # noqa: E501

    @validate_arguments
    def search_with_http_info(self, knowledge_base_query_dto: Annotated[
        KnowledgeBaseQueryDTO, Field(..., description="查询知识库请求")], **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'knowledge_base_query_dto'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['knowledge_base_query_dto'] is not None:
            _body_params = _params['knowledge_base_query_dto']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOPageResultKnowledgeBaseDTO",
        }

        return self.api_client.call_api(
            '/{0}/api/knowledge_base/search'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def delete(self, knowledge_base_delete_dto: Annotated[KnowledgeBaseDeleteDTO, Field(..., description="删除知识库")],
               **kwargs) -> ResultDTOBoolean:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the delete_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.delete_with_http_info(knowledge_base_delete_dto, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_with_http_info(self, knowledge_base_delete_dto: Annotated[
        KnowledgeBaseDeleteDTO, Field(..., description="删除知识库请求")], **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'knowledge_base_delete_dto'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['knowledge_base_delete_dto'] is not None:
            _body_params = _params['knowledge_base_delete_dto']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOBoolean",
        }

        return self.api_client.call_api(
            '/{0}/api/knowledge_base/delete'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def detail_upload(self,
                      knowledge_base_detail_upload_dto: Annotated[
                          KnowledgeBaseDetailUploadDTO, Field(..., description="知识库文件上传请求")],
                      **kwargs) -> ResultDTOBoolean:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the detail_upload_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.detail_upload_with_http_info(knowledge_base_detail_upload_dto, **kwargs)  # noqa: E501

    @validate_arguments
    def detail_upload_with_http_info(self, knowledge_base_detail_upload_dto: Annotated[
        KnowledgeBaseDetailUploadDTO, Field(..., description="知识库文件上传请求")], **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'knowledge_base_detail_upload_dto'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method detail_upload" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['knowledge_base_detail_upload_dto'] is not None:
            _body_params = _params['knowledge_base_detail_upload_dto']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOBoolean",
        }

        return self.api_client.call_api(
            '/{0}/api/knowledge_base/detail/upload'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def detail_update(self,
                      knowledge_base_detail_update_dto: Annotated[
                          KnowledgeBaseDetailUpdateDTO, Field(..., description="修改知识库详情请求")],
                      **kwargs) -> ResultDTOBoolean:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the detail_update_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.detail_update_with_http_info(knowledge_base_detail_update_dto, **kwargs)  # noqa: E501

    @validate_arguments
    def detail_update_with_http_info(self, knowledge_base_detail_update_dto: Annotated[
        KnowledgeBaseDetailUpdateDTO, Field(..., description="修改知识库详情请求")], **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'knowledge_base_detail_update_dto'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method detail_update" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['knowledge_base_detail_update_dto'] is not None:
            _body_params = _params['knowledge_base_detail_update_dto']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOBoolean",
        }

        return self.api_client.call_api(
            '/{0}/api/knowledge_base/detail/update'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def detail_search(self, knowledge_base_detail_query_dto: Annotated[
        KnowledgeBaseDetailQueryDTO, Field(..., description="查询知识库详情请求")],
                      **kwargs) -> ResultDTOPageResultKnowledgeBaseDetailDTO:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the detail_search_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.detail_search_with_http_info(knowledge_base_detail_query_dto, **kwargs)  # noqa: E501

    @validate_arguments
    def detail_search_with_http_info(self, knowledge_base_detail_query_dto: Annotated[
        KnowledgeBaseDetailQueryDTO, Field(..., description="查询知识库详情请求")], **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'knowledge_base_detail_query_dto'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method detail_search" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['knowledge_base_detail_query_dto'] is not None:
            _body_params = _params['knowledge_base_detail_query_dto']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOPageResultKnowledgeBaseDetailDTO",
        }

        return self.api_client.call_api(
            '/{0}/api/knowledge_base/detail/search'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def detail_delete(self, knowledge_base_detail_delete_dto: Annotated[
        KnowledgeBaseDetailDeleteDTO, Field(..., description="删除知识库详情请求")], **kwargs) -> ResultDTOBoolean:  # noqa: E501
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the detail_delete_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.detail_delete_with_http_info(knowledge_base_detail_delete_dto, **kwargs)  # noqa: E501

    @validate_arguments
    def detail_delete_with_http_info(self, knowledge_base_detail_delete_dto: Annotated[
        KnowledgeBaseDetailDeleteDTO, Field(..., description="删除知识库详情请求")], **kwargs) -> ApiResponse:  # noqa: E501

        _params = locals()

        _all_params = [
            'knowledge_base_detail_delete_dto'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method detail_delete" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['knowledge_base_detail_delete_dto'] is not None:
            _body_params = _params['knowledge_base_detail_delete_dto']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
                                          self.api_client.select_header_content_type(
                                              ['application/json']))
        if _content_types_list:
            _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['Authorization']  # noqa: E501

        _response_types_map = {
            '200': "ResultDTOBoolean",
        }

        return self.api_client.call_api(
            '/{0}/api/knowledge_base/detail/delete'.format(self.version()), 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8


from __future__ import annotations

import json
import pprint

from pydantic import BaseModel, Field, StrictStr


class ResetChatHistoryRequest(BaseModel):
    """
    重置对话
    """
    character_id: StrictStr = Field(..., alias="characterId", description="角色ID")
    user_id: StrictStr = Field(..., alias="userId", description="业务系统用户ID")
    __properties = ["characterId", "userId"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ResetChatHistoryRequest:
        """Create an instance of SysReminderRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ResetChatHistoryRequest:
        """Create an instance of SysReminderRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ResetChatHistoryRequest.parse_obj(obj)

        _obj = ResetChatHistoryRequest.parse_obj({
            "character_id": obj.get("characterId"),
            "user_id": obj.get("userId")
        })
        return _obj


